@@ -4,9 +4,9 @@ CMR_HOST = 'cmr.earthdata.nasa.gov'
 CMR_TIMEOUT = 30
 CMR_FORMAT_EXT = 'umm_json'
 CMR_GRANULE_PATH = f'/search/granules.{CMR_FORMAT_EXT}'
-CMR_COLLECTIONS = f'/search/collections'
+CMR_COLLECTIONS = '/search/collections'
 CMR_COLLECTIONS_PATH = f'{CMR_COLLECTIONS}.{CMR_FORMAT_EXT}'
-CMR_HEALTH_PATH = f'/search/health'
+CMR_HEALTH_PATH = '/search/health'
 CMR_PAGE_SIZE = 250
 EDL_HOST = 'urs.earthdata.nasa.gov'
 EDL_CLIENT_ID = 'BO_n7nTIlMljdvU6kRRB3g'
