@@ -14,3 +14,7 @@ HH_VV = 'HH+VV'
 HH_HV_VH_VV = 'HH+HV+VH+VV'
 FULL = 'full'
 UNKNOWN = 'UNKNOWN'
+# NISAR
+LH_LV="LH+LV"
+RH_RV="RH+RV"
+HH_HV_VV_VH="HH+HV+VV+VH"
