@@ -76,6 +76,9 @@ class JSONLite2StreamArray(JSONLiteStreamArray):
         if p.get('opera') is not None:
             result['s1o'] = p['opera']
         
+        if p.get('nisar') is not None:
+            result['nisar'] = p['nisar']
+        
         return result
 
     def getOutputType(self) -> str:
